# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegionGrowingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkConnectedThresholdImageFilterPython
else:
    import _itkConnectedThresholdImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkSimpleDataObjectDecoratorPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkArrayPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkImageRegionPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
class itkConnectedThresholdImageFilterEnums(object):
    r"""Proxy of C++ itkConnectedThresholdImageFilterEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    Connectivity_FaceConnectivity = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterEnums_Connectivity_FaceConnectivity
    
    Connectivity_FullConnectivity = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterEnums_Connectivity_FullConnectivity
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkConnectedThresholdImageFilterEnums
        __init__(self, arg0) -> itkConnectedThresholdImageFilterEnums

        Parameters
        ----------
        arg0: itkConnectedThresholdImageFilterEnums const &

        """
        _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterEnums_swiginit(self, _itkConnectedThresholdImageFilterPython.new_itkConnectedThresholdImageFilterEnums(*args))
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterEnums

# Register itkConnectedThresholdImageFilterEnums in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterEnums_swigregister(itkConnectedThresholdImageFilterEnums)

def itkConnectedThresholdImageFilterIF2IF2_New():
    return itkConnectedThresholdImageFilterIF2IF2.New()

class itkConnectedThresholdImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkConnectedThresholdImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedThresholdImageFilterIF2IF2_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedThresholdImageFilterIF2IF2_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_AddSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_ClearSeeds(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetSeeds(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> float"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetReplaceValue(self)

    def SetUpper(self, arg0):
        r"""
        SetUpper(self, arg0)

        Parameters
        ----------
        arg0: float

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetUpper(self, arg0)

    def SetLower(self, arg0):
        r"""
        SetLower(self, arg0)

        Parameters
        ----------
        arg0: float

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetLower(self, arg0)

    def SetUpperInput(self, arg0):
        r"""
        SetUpperInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetUpperInput(self, arg0)

    def SetLowerInput(self, arg0):
        r"""
        SetLowerInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetLowerInput(self, arg0)

    def GetUpper(self):
        r"""GetUpper(self) -> float"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetUpper(self)

    def GetLower(self):
        r"""GetLower(self) -> float"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetLower(self)

    def GetUpperInput(self):
        r"""GetUpperInput(self) -> itkSimpleDataObjectDecoratorF"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetUpperInput(self)

    def GetLowerInput(self):
        r"""GetLowerInput(self) -> itkSimpleDataObjectDecoratorF"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetLowerInput(self)
    OutputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_OutputEqualityComparableCheck
    
    InputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_InputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SameDimensionCheck
    
    IntConvertibleToInputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_IntConvertibleToInputCheck
    
    OutputOStreamWritableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_OutputOStreamWritableCheck
    

    def SetConnectivity(self, _arg):
        r"""
        SetConnectivity(self, _arg)

        Parameters
        ----------
        _arg: enum itkConnectedThresholdImageFilterEnums::Connectivity const

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_SetConnectivity(self, _arg)

    def GetConnectivity(self):
        r"""GetConnectivity(self) -> itkConnectedThresholdImageFilterEnums::Connectivity"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_GetConnectivity(self)
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedThresholdImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedThresholdImageFilterIF2IF2

        Create a new object of the class itkConnectedThresholdImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedThresholdImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedThresholdImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedThresholdImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedThresholdImageFilterIF2IF2 in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF2IF2_swigregister(itkConnectedThresholdImageFilterIF2IF2)

def itkConnectedThresholdImageFilterIF3IF3_New():
    return itkConnectedThresholdImageFilterIF3IF3.New()

class itkConnectedThresholdImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkConnectedThresholdImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedThresholdImageFilterIF3IF3_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedThresholdImageFilterIF3IF3_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_AddSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_ClearSeeds(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetSeeds(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> float"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetReplaceValue(self)

    def SetUpper(self, arg0):
        r"""
        SetUpper(self, arg0)

        Parameters
        ----------
        arg0: float

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetUpper(self, arg0)

    def SetLower(self, arg0):
        r"""
        SetLower(self, arg0)

        Parameters
        ----------
        arg0: float

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetLower(self, arg0)

    def SetUpperInput(self, arg0):
        r"""
        SetUpperInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetUpperInput(self, arg0)

    def SetLowerInput(self, arg0):
        r"""
        SetLowerInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorF const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetLowerInput(self, arg0)

    def GetUpper(self):
        r"""GetUpper(self) -> float"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetUpper(self)

    def GetLower(self):
        r"""GetLower(self) -> float"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetLower(self)

    def GetUpperInput(self):
        r"""GetUpperInput(self) -> itkSimpleDataObjectDecoratorF"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetUpperInput(self)

    def GetLowerInput(self):
        r"""GetLowerInput(self) -> itkSimpleDataObjectDecoratorF"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetLowerInput(self)
    OutputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_OutputEqualityComparableCheck
    
    InputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_InputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SameDimensionCheck
    
    IntConvertibleToInputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_IntConvertibleToInputCheck
    
    OutputOStreamWritableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_OutputOStreamWritableCheck
    

    def SetConnectivity(self, _arg):
        r"""
        SetConnectivity(self, _arg)

        Parameters
        ----------
        _arg: enum itkConnectedThresholdImageFilterEnums::Connectivity const

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_SetConnectivity(self, _arg)

    def GetConnectivity(self):
        r"""GetConnectivity(self) -> itkConnectedThresholdImageFilterEnums::Connectivity"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_GetConnectivity(self)
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedThresholdImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedThresholdImageFilterIF3IF3

        Create a new object of the class itkConnectedThresholdImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedThresholdImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedThresholdImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedThresholdImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedThresholdImageFilterIF3IF3 in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIF3IF3_swigregister(itkConnectedThresholdImageFilterIF3IF3)

def itkConnectedThresholdImageFilterISS2ISS2_New():
    return itkConnectedThresholdImageFilterISS2ISS2.New()

class itkConnectedThresholdImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkConnectedThresholdImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedThresholdImageFilterISS2ISS2_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedThresholdImageFilterISS2ISS2_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_AddSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_ClearSeeds(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetSeeds(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetReplaceValue(self)

    def SetUpper(self, arg0):
        r"""
        SetUpper(self, arg0)

        Parameters
        ----------
        arg0: short

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetUpper(self, arg0)

    def SetLower(self, arg0):
        r"""
        SetLower(self, arg0)

        Parameters
        ----------
        arg0: short

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetLower(self, arg0)

    def SetUpperInput(self, arg0):
        r"""
        SetUpperInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetUpperInput(self, arg0)

    def SetLowerInput(self, arg0):
        r"""
        SetLowerInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetLowerInput(self, arg0)

    def GetUpper(self):
        r"""GetUpper(self) -> short"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetUpper(self)

    def GetLower(self):
        r"""GetLower(self) -> short"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetLower(self)

    def GetUpperInput(self):
        r"""GetUpperInput(self) -> itkSimpleDataObjectDecoratorSS"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetUpperInput(self)

    def GetLowerInput(self):
        r"""GetLowerInput(self) -> itkSimpleDataObjectDecoratorSS"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetLowerInput(self)
    OutputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_OutputEqualityComparableCheck
    
    InputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_InputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SameDimensionCheck
    
    IntConvertibleToInputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_IntConvertibleToInputCheck
    
    OutputOStreamWritableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_OutputOStreamWritableCheck
    

    def SetConnectivity(self, _arg):
        r"""
        SetConnectivity(self, _arg)

        Parameters
        ----------
        _arg: enum itkConnectedThresholdImageFilterEnums::Connectivity const

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_SetConnectivity(self, _arg)

    def GetConnectivity(self):
        r"""GetConnectivity(self) -> itkConnectedThresholdImageFilterEnums::Connectivity"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_GetConnectivity(self)
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedThresholdImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedThresholdImageFilterISS2ISS2

        Create a new object of the class itkConnectedThresholdImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedThresholdImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedThresholdImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedThresholdImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedThresholdImageFilterISS2ISS2 in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS2ISS2_swigregister(itkConnectedThresholdImageFilterISS2ISS2)

def itkConnectedThresholdImageFilterISS3ISS3_New():
    return itkConnectedThresholdImageFilterISS3ISS3.New()

class itkConnectedThresholdImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkConnectedThresholdImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedThresholdImageFilterISS3ISS3_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedThresholdImageFilterISS3ISS3_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_AddSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_ClearSeeds(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetSeeds(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetReplaceValue(self)

    def SetUpper(self, arg0):
        r"""
        SetUpper(self, arg0)

        Parameters
        ----------
        arg0: short

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetUpper(self, arg0)

    def SetLower(self, arg0):
        r"""
        SetLower(self, arg0)

        Parameters
        ----------
        arg0: short

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetLower(self, arg0)

    def SetUpperInput(self, arg0):
        r"""
        SetUpperInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetUpperInput(self, arg0)

    def SetLowerInput(self, arg0):
        r"""
        SetLowerInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorSS const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetLowerInput(self, arg0)

    def GetUpper(self):
        r"""GetUpper(self) -> short"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetUpper(self)

    def GetLower(self):
        r"""GetLower(self) -> short"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetLower(self)

    def GetUpperInput(self):
        r"""GetUpperInput(self) -> itkSimpleDataObjectDecoratorSS"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetUpperInput(self)

    def GetLowerInput(self):
        r"""GetLowerInput(self) -> itkSimpleDataObjectDecoratorSS"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetLowerInput(self)
    OutputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_OutputEqualityComparableCheck
    
    InputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_InputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SameDimensionCheck
    
    IntConvertibleToInputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_IntConvertibleToInputCheck
    
    OutputOStreamWritableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_OutputOStreamWritableCheck
    

    def SetConnectivity(self, _arg):
        r"""
        SetConnectivity(self, _arg)

        Parameters
        ----------
        _arg: enum itkConnectedThresholdImageFilterEnums::Connectivity const

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_SetConnectivity(self, _arg)

    def GetConnectivity(self):
        r"""GetConnectivity(self) -> itkConnectedThresholdImageFilterEnums::Connectivity"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_GetConnectivity(self)
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedThresholdImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedThresholdImageFilterISS3ISS3

        Create a new object of the class itkConnectedThresholdImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedThresholdImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedThresholdImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedThresholdImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedThresholdImageFilterISS3ISS3 in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterISS3ISS3_swigregister(itkConnectedThresholdImageFilterISS3ISS3)

def itkConnectedThresholdImageFilterIUC2IUC2_New():
    return itkConnectedThresholdImageFilterIUC2IUC2.New()

class itkConnectedThresholdImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkConnectedThresholdImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_AddSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_ClearSeeds(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetSeeds(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetReplaceValue(self)

    def SetUpper(self, arg0):
        r"""
        SetUpper(self, arg0)

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetUpper(self, arg0)

    def SetLower(self, arg0):
        r"""
        SetLower(self, arg0)

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetLower(self, arg0)

    def SetUpperInput(self, arg0):
        r"""
        SetUpperInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetUpperInput(self, arg0)

    def SetLowerInput(self, arg0):
        r"""
        SetLowerInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetLowerInput(self, arg0)

    def GetUpper(self):
        r"""GetUpper(self) -> unsigned char"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetUpper(self)

    def GetLower(self):
        r"""GetLower(self) -> unsigned char"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetLower(self)

    def GetUpperInput(self):
        r"""GetUpperInput(self) -> itkSimpleDataObjectDecoratorUC"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetUpperInput(self)

    def GetLowerInput(self):
        r"""GetLowerInput(self) -> itkSimpleDataObjectDecoratorUC"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetLowerInput(self)
    OutputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_OutputEqualityComparableCheck
    
    InputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_InputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SameDimensionCheck
    
    IntConvertibleToInputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_IntConvertibleToInputCheck
    
    OutputOStreamWritableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_OutputOStreamWritableCheck
    

    def SetConnectivity(self, _arg):
        r"""
        SetConnectivity(self, _arg)

        Parameters
        ----------
        _arg: enum itkConnectedThresholdImageFilterEnums::Connectivity const

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_SetConnectivity(self, _arg)

    def GetConnectivity(self):
        r"""GetConnectivity(self) -> itkConnectedThresholdImageFilterEnums::Connectivity"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_GetConnectivity(self)
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedThresholdImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedThresholdImageFilterIUC2IUC2

        Create a new object of the class itkConnectedThresholdImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedThresholdImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedThresholdImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedThresholdImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedThresholdImageFilterIUC2IUC2 in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC2IUC2_swigregister(itkConnectedThresholdImageFilterIUC2IUC2)

def itkConnectedThresholdImageFilterIUC3IUC3_New():
    return itkConnectedThresholdImageFilterIUC3IUC3.New()

class itkConnectedThresholdImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkConnectedThresholdImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_PrintSelf(self, os, indent)

    def SetSeed(self, seed):
        r"""
        SetSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetSeed(self, seed)

    def AddSeed(self, seed):
        r"""
        AddSeed(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_AddSeed(self, seed)

    def ClearSeeds(self):
        r"""ClearSeeds(self)"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_ClearSeeds(self)

    def GetSeeds(self):
        r"""GetSeeds(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetSeeds(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetReplaceValue(self)

    def SetUpper(self, arg0):
        r"""
        SetUpper(self, arg0)

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetUpper(self, arg0)

    def SetLower(self, arg0):
        r"""
        SetLower(self, arg0)

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetLower(self, arg0)

    def SetUpperInput(self, arg0):
        r"""
        SetUpperInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetUpperInput(self, arg0)

    def SetLowerInput(self, arg0):
        r"""
        SetLowerInput(self, arg0)

        Parameters
        ----------
        arg0: itkSimpleDataObjectDecoratorUC const *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetLowerInput(self, arg0)

    def GetUpper(self):
        r"""GetUpper(self) -> unsigned char"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetUpper(self)

    def GetLower(self):
        r"""GetLower(self) -> unsigned char"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetLower(self)

    def GetUpperInput(self):
        r"""GetUpperInput(self) -> itkSimpleDataObjectDecoratorUC"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetUpperInput(self)

    def GetLowerInput(self):
        r"""GetLowerInput(self) -> itkSimpleDataObjectDecoratorUC"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetLowerInput(self)
    OutputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_OutputEqualityComparableCheck
    
    InputEqualityComparableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_InputEqualityComparableCheck
    
    InputConvertibleToOutputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SameDimensionCheck
    
    IntConvertibleToInputCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_IntConvertibleToInputCheck
    
    OutputOStreamWritableCheck = _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_OutputOStreamWritableCheck
    

    def SetConnectivity(self, _arg):
        r"""
        SetConnectivity(self, _arg)

        Parameters
        ----------
        _arg: enum itkConnectedThresholdImageFilterEnums::Connectivity const

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_SetConnectivity(self, _arg)

    def GetConnectivity(self):
        r"""GetConnectivity(self) -> itkConnectedThresholdImageFilterEnums::Connectivity"""
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_GetConnectivity(self)
    __swig_destroy__ = _itkConnectedThresholdImageFilterPython.delete_itkConnectedThresholdImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedThresholdImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedThresholdImageFilterIUC3IUC3

        Create a new object of the class itkConnectedThresholdImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedThresholdImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedThresholdImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedThresholdImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedThresholdImageFilterIUC3IUC3 in _itkConnectedThresholdImageFilterPython:
_itkConnectedThresholdImageFilterPython.itkConnectedThresholdImageFilterIUC3IUC3_swigregister(itkConnectedThresholdImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def connected_threshold_image_filter(*args: itkt.ImageLike,  seed: Sequence[int]=..., replace_value: float=..., upper: float=..., lower: float=..., upper_input=..., lower_input=..., connectivity=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ConnectedThresholdImageFilter"""
    import itk

    kwarg_typehints = { 'seed':seed,'replace_value':replace_value,'upper':upper,'lower':lower,'upper_input':upper_input,'lower_input':lower_input,'connectivity':connectivity }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ConnectedThresholdImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def connected_threshold_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKRegionGrowing.ConnectedThresholdImageFilter
    connected_threshold_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    connected_threshold_image_filter.__doc__ = filter_object.__doc__



